@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 9927 2017-04-29 14:17:02Z David $
+# $Id: Patch.py 9936 2017-05-01 15:48:55Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
-# $Revision: 9927 $
+# $Date: 2017-05-01 23:48:55 +0800 (Mon, 01 May 2017) $
+# $Revision: 9936 $
 #
 # Contributors:
 #  Bear
@@ -36,8 +36,8 @@ def attachDebugSettings(settingsDict):
     except ImportError:
         pass
     else:
-        settingsDict['INSTALLED_APPS'] += ['django_extensions',]
-        settingsDict['INSTALLED_APPS'] += ['debug_toolbar', ]
+        settingsDict['INSTALLED_APPS'] += ('django_extensions', )
+        settingsDict['INSTALLED_APPS'] += ('debug_toolbar', )
         settingsDict['MIDDLEWARE_CLASSES'] += (
             "debug_toolbar.middleware.DebugToolbarMiddleware", )
         defaultInternalIP = {
