@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9927 2017-04-29 14:17:02Z David $
+# $Id: __init__.py 9947 2017-05-04 10:37:30Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
-# $Revision: 9927 $
+# $Date: 2017-05-04 18:37:30 +0800 (Thu, 04 May 2017) $
+# $Revision: 9947 $
 
 import os
 import sys
@@ -465,7 +465,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
             'debug_file': {
                 'level': 'DEBUG',
                 'class': 'logging.FileHandler',
-                'filename': os.path.join(settingsDict['BASE_DIR'], 'debug.log'),
+                'filename': os.path.join(projectPath, 'debug.log'),
             },        
         })
         loggingDefaults['LOGGING']['loggers'].update({
@@ -735,31 +735,32 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         pass
     else:
         import Iuno.member
-    
-    iunoMemberDefaults = {
-        'IUNO_MEMBER_ENABLE': False,
-        'IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE': False,
-        'IUNO_MEMBER_GMAIL_LOGIN_ENABLE': False,
-        'IUNO_MEMBER_YAHOO_LOGIN_ENABLE': False,
-        'IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE': False,
-    }
+        
+        iunoMemberDefaults = {
+            'IUNO_MEMBER_ENABLE': False,
+            'IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE': False,
+            'IUNO_MEMBER_GMAIL_LOGIN_ENABLE': False,
+            'IUNO_MEMBER_YAHOO_LOGIN_ENABLE': False,
+            'IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE': False,
+        }
 
-    update(settingsDict, iunoMemberDefaults)
-    
-    populateEnvToSettings(iunoMemberDefaults.keys(), settingsDict, 
-                          evalKeys=iunoMemberDefaults.keys())
+        update(settingsDict, iunoMemberDefaults)
+        
+        populateEnvToSettings(iunoMemberDefaults.keys(), settingsDict, 
+                            evalKeys=iunoMemberDefaults.keys())
 
-    if settingsDict['IUNO_MEMBER_ENABLE']:
-        Iuno.member.attachSettings(
-                        settingsDict,
-                        settingsDict['IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE'],
-                        settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
-                        settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
-                        settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
-                    )
-    else: # IUNO_MEMBER_ENABLE = False
-        if warns:
-            warnPackageDisable('Iuno.member', settingsDict, iunoMemberDefaults)
+        if settingsDict['IUNO_MEMBER_ENABLE']:
+            Iuno.member.attachSettings(
+                            settingsDict,
+                            settingsDict['IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE'],
+                            settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
+                            settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
+                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
+                        )
+        else: # IUNO_MEMBER_ENABLE = False
+            if warns:
+                warnPackageDisable('Iuno.member', settingsDict, 
+                                   iunoMemberDefaults)
     #=========================================================================
 
     #=========================================================================
@@ -771,25 +772,24 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     else:
         import Iuno.shop
     
-    iunoShopDefaults = {
-        'IUNO_SHOP_ENABLE': False,
-        'IUNO_SHOP_PAYPAL_ENABLE': False,
-    }
+        iunoShopDefaults = {
+            'IUNO_SHOP_ENABLE': False,
+            'IUNO_SHOP_PAYPAL_ENABLE': False,
+        }
 
-    update(settingsDict, iunoShopDefaults)
-    
-    populateEnvToSettings(iunoShopDefaults.keys(), settingsDict, 
-                          evalKeys=iunoShopDefaults.keys())
+        update(settingsDict, iunoShopDefaults)
+        
+        populateEnvToSettings(iunoShopDefaults.keys(), settingsDict, 
+                            evalKeys=iunoShopDefaults.keys())
 
-    if settingsDict['IUNO_SHOP_ENABLE']:
-        Iuno.shop.attachSettings(
-                        settingsDict,
-                        settingsDict['IUNO_SHOP_PAYPAL_ENABLE'],
-                    )
-
-    else: # IUNO_SHOP_ENABLE = False
-        if warns:
-            warnPackageDisable('Iuno.shop', settingsDict, iunoShopDefaults)
+        if settingsDict['IUNO_SHOP_ENABLE']:
+            Iuno.shop.attachSettings(
+                            settingsDict,
+                            settingsDict['IUNO_SHOP_PAYPAL_ENABLE'],
+                        )
+        else: # IUNO_SHOP_ENABLE = False
+            if warns:
+                warnPackageDisable('Iuno.shop', settingsDict, iunoShopDefaults)
     #=========================================================================
     
     #=========================================================================
@@ -825,7 +825,7 @@ def detectDebug(settingsDict):
     
     @param settingsDict Settings dict.
     """
-    _DEBUG = (True if settingsDict['SERVER_MODE'] not in (STAGE, PRODUCTION) 
-                   else False)
+    _DEBUG = (True if settingsDict.get('SERVER_MODE', DEVELOPMENT) not in (
+        STAGE, PRODUCTION) else False)
 
     return _DEBUG
