@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9716 2017-01-13 13:24:44Z Lavender $
+# $Id: __init__.py 9947 2017-05-04 10:37:30Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2017-01-13 21:24:44 +0800 (Fri, 13 Jan 2017) $
-# $Revision: 9716 $
+# $Author: David $ (last)
+# $Date: 2017-05-04 18:37:30 +0800 (Thu, 04 May 2017) $
+# $Revision: 9947 $
 
 import os
 import sys
@@ -66,10 +66,7 @@ def attachSettings(settingsDict, enableFacebook=False, enableGoogle=False,
     # Email.
     emailDefaults = {
         'ACCOUNT_EMAIL_CONFIRMATION_REQUIRED' : True,
-        'EMAIL_BACKEND' : 'django.core.mail.backends.smtp.EmailBackend',
     }
-    
-    warnWithout('EMAIL_BACKEND', settingsDict, emailDefaults)
 
     update(settingsDict, emailDefaults)
     #=========================================================================
